check

package
v0.0.0-...-098145f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2021 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func URL

func URL(url string) error

URL checks given url for status code and set appropiate Prometheus metric

Types

type Doer

type Doer interface {
	Do(req *http.Request) (*http.Response, error)
}

Doer is an interface that allows us to replace http.Client with any other struct implementing Do() function.

Jump to